@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0704';
+our $VERSION = '0.0705';
 
 use Math::Random::Discrete;
 use MIDI::Simple ();
@@ -216,7 +216,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0704
+version 0.0705
 
 =head1 SYNOPSIS
 
@@ -225,35 +225,35 @@ version 0.0704
   use Music::Scales;
 
   my $mdp = Music::Duration::Partition->new(
-    size => 8, # 2 measures in 4/4 time
-    pool => [qw(hn dqn qn en)],
+    size => 8,                  # 2 measures in 4/4 time
+    pool => [qw(hn dqn qn en)], # Made from these durations
   );
 
-  $mdp->pool_select(sub { ... }); # Optional
+  $mdp->pool_select(sub { ... }); # optional
 
-  my $motif = $mdp->motif;
+  my $motif = $mdp->motif; # Random list-ref of pool members
 
   my @scale = get_scale_MIDI('C', 4, 'major');
 
   my $score = MIDI::Simple->new_score;
 
-  for my $n (0 .. 31) { # 4 loops over the motif
+  for my $n (0 .. 31) { # 32/8=4 loops over the motif
     $score->n($motif->[$n % @$motif], $scale[int rand @scale]);
   }
 
   $score->write_score('motif.mid');
 
-  # The pool may also be made of duration ticks
+  # The pool may also be weighted
   $mdp = Music::Duration::Partition->new(
     size    => 100,
-    pool    => [qw(d50 d25)],
-    weights => [0.7, 0.3], # Optional
+    pool    => [qw(d50  d25)],
+    weights => [   0.7, 0.3], # optional
   );
 
   # The pool may also be grouped
   $mdp = Music::Duration::Partition->new(
     pool   => [qw(hn qn tqn)],
-    groups => [0, 0, 3], # Optional
+    groups => [   1, 1, 3], # optional
   );
 
 =head1 DESCRIPTION
@@ -296,9 +296,9 @@ motif.
 
 Default: C<[ keys %MIDI::Simple::Length ]> (wn, hn, qn, ...)
 
-This can be B<either> a list of duration names, as in the example, or
-duration values, specified with a preceding 'd'.  A mixture of both is
-not well defined. YMMV
+This can be B<either> a list of duration names, or duration values,
+specified with a preceding 'd'.  A mixture of both is not well
+defined. YMMV
 
 =head2 pool_select
 
@@ -330,9 +330,9 @@ pool item is selected in sequence.
 
 The number of groups must equal the number of pool entries.
 
-Default: Zero for each pool entry
+Default: C<0> for each pool entry
 
-* Zero and one mean the same thing for grouping.  So if needed, an
+* C<0> and C<1> mean the same thing for grouping.  So if needed, an
 entry should have a value greater than one.
 
 =head2 remainder
